=======
History
=======

1.0.0 (2020-08-20)
------------------
* Deidentification implementing standard DICOM confidentiality profile and options
* Basic imagedata processing
* Support for safe private tags
* Documentation
* Test coverage over 90%

0.3.1 (2020-08-02)
------------------
* Alpha development

0.1.0 (2020-06-02)
------------------

* First release on PyPI.
